@@ -85,6 +85,14 @@ impl Client {
     self.kv.delete_both_session(self, key)
   }
 
+  /*
+  pub async fn kv_folder_watch<S: Into<String>>(&self, folder: S) -> Result<bool, String> {
+    let res = self.kv.watch_tree(self, folder).await;
+
+    Ok(true)
+  }
+   */
+
   pub fn session_set(&self, lock_delay: String, name: String, node: String,
                      behavior: String, ttl: String) -> String {
     let mut s = session::Session::new();
@@ -110,16 +118,57 @@ impl Client {
   pub fn session_delete(&self, sid: &str) -> String {
     self.session.delete(self, sid)
   }
+
 }
 
 #[cfg(test)]
 mod tests {
   use crate::Client;
   use base64::Config;
+  use tokio::sync::mpsc;
   use crate::config;
   use crate::pkg::CustomError;
   use crate::kv::KVPair;
 
+  /*
+  // #[test]
+  #[tokio::test]
+  async fn test_kv_folder_watch() {
+    env_logger::init();
+    for i in 0..3 {
+      log::info!("i --- {:?}", i);
+    }
+    log::info!("log输出");
+    let host = config::CONFIG["consul_addr"];
+    let client = Client::new(host, 8500);
+    let res = client.kv_folder_watch("foo").await;
+  }
+   */
+
+  /*
+  #[tokio::test]
+  async fn test_kv_folder_watch_getnodes() {
+    env_logger::init();
+    for i in 0..3 {
+      log::info!("i --- {:?}", i);
+    }
+    log::info!("log输出");
+    let host = config::CONFIG["consul_addr"];
+    let client = Client::new(host, 8500);
+    let mut res = false;
+    let (sx, mut rx) = mpsc::channel(1);
+
+    tokio::task::spawn({
+      let resx = client.kv_folder_watch("foo").await.unwrap();
+      sx.send(resx).await.unwrap();
+    });
+
+    while let Some(resx) = rx.recv().await {
+      log::info!("resx --- {:?}", resx);
+    }
+  }
+   */
+
   #[test]
   fn test_kv_delete_both_session() {
     let host = config::CONFIG["consul_addr"];
